import React, { useState, useEffect } from 'react'
import { routes } from './routes'
import { Layout, Menu, Select, Space, Button, Modal, Input } from 'antd'
import { Routes, Route, Link, Navigate, useLocation } from 'react-router-dom'
import styled from 'styled-components'
const { Content, Sider, Header } = Layout

const SidebarDiv = styled.div`
  .sidebar {
    overflow: auto;
    height: 100vh;
    position: fixed;
    left: 0;
    bottom: 0;
  }
  .content {
    overflow: initial;
    margin-left: 200px;
  }
  .headerLogo {
    height: 32px;
    margin: 16px;
    background: rgba(255, 255, 255, 0.2);
    text-align: center;
    color: #fff;
    line-height: 32px;
  }
`

const Main = () => {
  const { pathname } = useLocation()
  const [currentSide, setCurrentSide] = useState('1')
  const [isAddProject, setIsAddProject] = useState(false)
  const [projectSetting, setProjectSetting] = useState(false)
  const [projectName, setProjectName] = useState(null)

  const menus = routes.map(item => {
    return {
      key: item.path,
      label: <Link to={item.path}>{item.title}</Link>,
    }
  })
  const openJupyterlab = () => {
    window.open(process.env.REACT_APP_JPT, '_target')
  }
  menus.push({
    key: 'jupyterlab',
    label: <div onClick={openJupyterlab}>可视化编程</div>,
  })

  let childrenList = []
  const routesInfo = routes.map(item => {
    if (item.children.length > 0) {
      childrenList = childrenList.concat(...item.children)
    }
    return {
      path: item.path,
      exact: item?.exact,
      component: item.component,
    }
  })
  const list = routesInfo.concat(...childrenList)

  useEffect(() => {
    setCurrentSide(pathname)
  }, [pathname])

  const onSelectSide = val => {
    setCurrentSide(val.key)
  }

  return (
    <SidebarDiv>
      <Layout>
        <Layout hasSider>
          <Sider className="sidebar">
            <div className="headerLogo">AI平台</div>
            <Menu
              theme="dark"
              mode="inline"
              items={menus}
              selectedKeys={currentSide}
              onSelect={onSelectSide}
            />
          </Sider>
          <Content className="content">
            <Routes>
              {list.map((route, index) => (
                <Route
                  key={index}
                  path={route.path}
                  exact={route?.exact}
                  element={<route.component />}
                />
              ))}
              <Route path="/" element={<Navigate to="datasource" replace />} />
            </Routes>
          </Content>
        </Layout>
      </Layout>
    </SidebarDiv>
  )
}

export default Main
